@@ -15,17 +15,18 @@
 #
 
 from typing import Union
+
 import requests
+
 from pysisu.formats import LatestAnalysisResultsFormats, Table
 from pysisu.latest_analysis_result import to_table
+from pysisu.proto.sisu.v1.api import (AnalysesListResponse,
+                                      AnalysisRunResultsResponse,
+                                      DataSetsResponse, DataSourceListResponse,
+                                      GetAnalysisFiltersResponse,
+                                      MetricsListResponse,
+                                      SetAnalysisFiltersRequest)
 from pysisu.query_helpers import build_url, pathjoin
-from pysisu.proto.sisu.v1.api import (
-    AnalysesListResponse,
-    AnalysisRunResultsResponse,
-    MetricsListResponse,
-    DataSourceListResponse,
-    DataSetsResponse,
-)
 
 
 class PySisuBaseException(Exception):
@@ -77,7 +78,7 @@ class PySisu:
             return result
 
         kda_result = result.analysis_result.key_driver_analysis_result
-        subgroups = kda_result.subgroups
+        subgroups = kda_result.segments
 
         if params.get("limit"):
             params["limit"] -= len(subgroups)
@@ -100,15 +101,15 @@ class PySisu:
             True,
             format=LatestAnalysisResultsFormats.PROTO,
         )
-        kda_result.subgroups = (
+        kda_result.segments = (
             subgroups
-            + next_page.analysis_result.key_driver_analysis_result.subgroups
+            + next_page.analysis_result.key_driver_analysis_result.segments
         )
         return result
 
-    def _call_sisu_api(self, url_path: int, request_method="get") -> dict:
-        headers = headers = {"Authorization": self._api_key}
-        r = requests.request(request_method, url_path, headers=headers)
+    def _call_sisu_api(self, url_path: int, request_method="get", json=None) -> dict:
+        headers = headers = {"Authorization": self._api_key, "User-Agent": "PySisu"}
+        r = requests.request(request_method, url_path, headers=headers, json=json)
         if r.status_code != 200:
             raise PySisuInvalidResponseFromServer(
                 "Result did not complete", r.content
@@ -156,9 +157,22 @@ class PySisu:
     def data_sources(self) -> DataSourceListResponse:
         path = ["api/v1/data_sources"]
         url_path = build_url(self._url, pathjoin(*path), {})
-        return DataSourceListResponse().from_dict(self._call_sisu_api(url_path))
+        return DataSourceListResponse().from_dict(
+            self._call_sisu_api(url_path)
+        )
 
     def datasets(self) -> DataSetsResponse:
         path = ["api/v1/datasets"]
         url_path = build_url(self._url, pathjoin(*path), {})
         return DataSetsResponse().from_dict(self._call_sisu_api(url_path))
+
+    def get_filters(self, analysis_id: int) -> GetAnalysisFiltersResponse:
+        path = [f"api/v1/analyses/{analysis_id}/filters"]
+        url_path = build_url(self._url, pathjoin(*path), {})
+        return GetAnalysisFiltersResponse().from_dict(self._call_sisu_api(url_path))
+
+    def set_filters(self, analysis_id: int , expr: SetAnalysisFiltersRequest):
+        path = [f"api/v1/analyses/{analysis_id}/filters"]
+        url_path = build_url(self._url, pathjoin(*path), {})
+        expr = expr.to_dict() if isinstance(expr, SetAnalysisFiltersRequest) else expr
+        return self._call_sisu_api(url_path, request_method="put", json=expr)
